"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.attachPrimaryVariantCommands = void 0;
var _executeSetPrimaryVariantCommand = require("./primaryVariant/executeSetPrimaryVariantCommand");
var _utils = require("../utils");
const getStringOrUndefined = value => {
  return typeof value === "string" && !!value ? value : undefined;
};

/**
 * Command to set a primary variant does not require a region because it is already contained inside the stack output.
 */
const attachPrimaryVariantCommands = params => {
  const {
    yargs,
    context
  } = params;
  yargs.command("set-primary-variant", `Set a deployed system as primary variant.`, () => {
    yargs.example("$0 set-primary-variant --env=dev --primary=blue --secondary=green", "");
    yargs.example("$0 set-primary-variant --env=dev --primary=green --secondary=green", "");
    yargs.option("env", {
      describe: `Environment`,
      type: "string",
      required: true
    });
    yargs.option("confirm", {
      describe: "Confirm deployment",
      type: "boolean",
      required: false
    });
    yargs.option("primary", {
      describe: `Primary variant`,
      type: "string",
      required: true
    }).check(args => {
      (0, _utils.validateVariantName)({
        variant: args.primary
      });
      return true;
    });
    yargs.option("secondary", {
      describe: `Secondary variant`,
      type: "string",
      required: true
    }).check(args => {
      (0, _utils.validateVariantName)({
        variant: args.secondary
      });
      return true;
    });
  }, async argv => {
    return (0, _executeSetPrimaryVariantCommand.executeSetPrimaryVariantCommand)({
      primary: getStringOrUndefined(argv.primary),
      secondary: getStringOrUndefined(argv.secondary),
      env: argv.env,
      confirm: argv.confirm === true || argv.confirm === "true"
    }, context);
  });
};
exports.attachPrimaryVariantCommands = attachPrimaryVariantCommands;

//# sourceMappingURL=attachPrimaryVariantCommands.js.map