"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SinglePackageBuilder = void 0;
var _BasePackagesBuilder = require("./BasePackagesBuilder");
var _chalk = require("chalk");
var _utils = require("../../utils");
class SinglePackageBuilder extends _BasePackagesBuilder.BasePackagesBuilder {
  async build() {
    const pkg = this.packages[0];
    const context = this.context;
    const inputs = this.inputs;
    const {
      env,
      debug,
      variant,
      region
    } = inputs;
    const pkgName = pkg.name;
    const pkgRelativePath = (0, _chalk.gray)(`(${pkg.paths.relative})`);
    context.info(`Building %s package...`, `${pkgName} ${pkgRelativePath}`);
    const options = {
      env,
      variant,
      region,
      debug,
      cwd: pkg.paths.root
    };
    const config = (0, _utils.requireConfigWithExecute)(pkg.paths.config, {
      options,
      context
    });
    const hasBuildCommand = config.commands && typeof config.commands.build === "function";
    if (!hasBuildCommand) {
      throw new Error("Build command not found.");
    }
    await config.commands.build(options);
  }
}
exports.SinglePackageBuilder = SinglePackageBuilder;

//# sourceMappingURL=SinglePackageBuilder.js.map