"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.deployCommand = void 0;
var _utils = require("../utils");
var _plugins = require("../plugins");
var _PackagesBuilder = require("./buildPackages/PackagesBuilder");
var _pulumiLoginSelectStack = require("./deploy/pulumiLoginSelectStack");
var _executeDeploy = require("./deploy/executeDeploy");
var _executePreview = require("./deploy/executePreview");
var _executeRefresh = require("./deploy/executeRefresh");
var _promises = require("node:timers/promises");
const deployCommand = (params, context) => {
  const command = (0, _utils.createPulumiCommand)({
    name: "deploy",
    createProjectApplicationWorkspace: params.build,
    telemetry: true,
    command: async commandParams => {
      const {
        inputs,
        context,
        projectApplication,
        pulumi,
        getDuration
      } = commandParams;
      const {
        env,
        variant,
        folder,
        build,
        deploy
      } = inputs;
      const hookArgs = {
        context,
        env,
        variant,
        inputs,
        projectApplication
      };
      context.info("Webiny version: %s", context.version);
      console.log();

      // Just so the version stays on the screen for a second, before the process continues.
      await (0, _promises.setTimeout)(1000);
      if (build) {
        await (0, _utils.runHook)({
          hook: "hook-before-build",
          args: hookArgs,
          context
        });
        console.log();
        const builder = new _PackagesBuilder.PackagesBuilder({
          packages: projectApplication.packages,
          inputs,
          context
        });
        await builder.build();
        console.log();
        await (0, _utils.runHook)({
          hook: "hook-after-build",
          args: hookArgs,
          context
        });
      } else {
        context.info("Skipping building of packages.");
      }
      console.log();
      if (!deploy) {
        context.info("Skipping project application deployment.");
        return;
      }
      await (0, _utils.runHook)({
        hook: _plugins.BeforeDeployPlugin.type,
        args: hookArgs,
        context
      });
      try {
        await (0, _pulumiLoginSelectStack.pulumiLoginSelectStack)({
          inputs,
          projectApplication,
          pulumi
        });
      } catch (ex) {
        context.error(ex.message);
        throw ex;
      }
      console.log();

      // A Pulumi refresh might be executed before the deploy. For example,
      // this is needed if the user run the watch command prior to the deploy.
      await (0, _executeRefresh.executeRefresh)(commandParams);
      if (inputs.preview) {
        await (0, _executePreview.executePreview)(commandParams);
      } else {
        await (0, _executeDeploy.executeDeploy)(commandParams);
      }
      console.log();
      await (0, _utils.runHook)({
        hook: "hook-after-deploy",
        args: hookArgs,
        context
      });
      await (0, _utils.notify)({
        message: `"${folder}" stack deployed in ${getDuration()}.`,
        timeout: 1
      });
    }
  });
  return command(params, context);
};
exports.deployCommand = deployCommand;

//# sourceMappingURL=deploy.js.map