"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeRefresh = void 0;
var _utils = require("../../utils");
var _ora = _interopRequireDefault(require("ora"));
var _ciInfo = require("ci-info");
var _env = require("../../utils/env");
const executeRefresh = async ({
  inputs,
  context,
  pulumi
}) => {
  const mustRefreshBeforeDeploy = (0, _utils.getMustRefreshBeforeDeploy)(context);
  if (!mustRefreshBeforeDeploy) {
    return;
  }

  // We always show deployment logs when doing previews.
  const showDeploymentLogs = _ciInfo.isCI || inputs.deploymentLogs;
  const getDeploymentDuration = (0, _utils.measureDuration)();
  const spinner = (0, _ora.default)("Refreshing Pulumi state...");
  try {
    const subprocess = pulumi.run({
      command: ["refresh", "--yes"],
      execa: {
        args: {
          debug: !!inputs.debug
        },
        env: (0, _env.createEnvConfiguration)({
          configurations: [(0, _env.withRegion)(inputs), (0, _env.withEnv)(inputs), (0, _env.withEnvVariant)(inputs), (0, _env.withProjectName)(context)]
        })
      }
    });
    if (showDeploymentLogs) {
      subprocess.stdout.pipe(process.stdout);
      subprocess.stderr.pipe(process.stderr);
      await subprocess;
    } else {
      spinner.start();
      await subprocess;
    }
    (0, _utils.unsetMustRefreshBeforeDeploy)(context);
    const message = `Pulumi state refreshed in ${getDeploymentDuration()}.`;
    if (showDeploymentLogs) {
      context.success(message);
    } else {
      spinner.succeed(message);
    }
  } catch (e) {
    // If the deployment logs were already shown, we don't want to do anything.
    if (showDeploymentLogs) {
      throw e;
    }
    spinner.fail(`Refresh failed. For more details, please check the error logs below.`);
    console.log();
    console.log(e.stderr || e.stdout || e.message);
    throw e;
  }
};
exports.executeRefresh = executeRefresh;

//# sourceMappingURL=executeRefresh.js.map