"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pulumiLoginSelectStack = void 0;
var _utils = require("../../utils");
var _env = require("../../utils/env");
const pulumiLoginSelectStack = async ({
  inputs,
  projectApplication,
  pulumi
}) => {
  const {
    env,
    variant
  } = inputs;
  await (0, _utils.login)(projectApplication);
  const PULUMI_SECRETS_PROVIDER = process.env.PULUMI_SECRETS_PROVIDER;
  const stackName = (0, _utils.getStackName)({
    env,
    variant
  });
  await pulumi.run({
    command: ["stack", "select", stackName],
    args: {
      create: true,
      secretsProvider: PULUMI_SECRETS_PROVIDER
    },
    execa: {
      env: (0, _env.createEnvConfiguration)({
        configurations: [(0, _env.withPulumiConfigPassphrase)()]
      })
    }
  });

  /**
   * A region from the input or process CANNOT be different to the region from the stack.
   * Also, if there is no stack, everything is ok.
   */
  const region = inputs.region || process.env.AWS_REGION;
  const skip = ["core", "blueGreen"].includes(projectApplication.id);
  if (!skip) {
    const coreStack = (0, _utils.getStackOutput)({
      ...inputs,
      folder: "apps/core"
    });
    if (coreStack.region && coreStack.region !== region) {
      throw new Error(`Core App Region mismatch. Input: "${inputs.region || "none"}", process: "${process.env.AWS_REGION || "none"}". In Core stack: "${coreStack.region}". This can happen if you try to deploy a stack to a region different to the Core application region.`);
    }
  }
  const targetStack = (0, _utils.getStackOutput)({
    ...inputs
  });
  if (!targetStack?.region || targetStack.region === region) {
    return;
  }
  throw new Error(`Region mismatch. Input: "${inputs.region || "none"}", process: "${process.env.AWS_REGION || "none"}". In stack: "${targetStack.region}". This can happen if you try to deploy a stack to a region other than it was initially deployed.`);
};
exports.pulumiLoginSelectStack = pulumiLoginSelectStack;

//# sourceMappingURL=pulumiLoginSelectStack.js.map