"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.destroyCommand = void 0;
var _utils = require("../utils");
var _env = require("../utils/env");
const destroyCommand = exports.destroyCommand = (0, _utils.createPulumiCommand)({
  name: "destroy",
  // We want to create a workspace just because there are cases where the destroy command is called
  // without the deployment happening initially (e.g. CI/CD scaffold's `pullRequestClosed.yml` workflow).
  createProjectApplicationWorkspace: true,
  command: async ({
    inputs,
    context,
    projectApplication,
    pulumi,
    getDuration
  }) => {
    const {
      env,
      variant,
      folder
    } = inputs;
    const stackName = (0, _utils.getStackName)({
      env,
      variant
    });
    let stackExists = true;
    try {
      const PULUMI_SECRETS_PROVIDER = process.env.PULUMI_SECRETS_PROVIDER;
      await pulumi.run({
        command: ["stack", "select", stackName],
        args: {
          secretsProvider: PULUMI_SECRETS_PROVIDER
        },
        execa: {
          env: (0, _env.createEnvConfiguration)({
            configurations: [(0, _env.withPulumiConfigPassphrase)()]
          })
        }
      });
    } catch (e) {
      stackExists = false;
    }
    if (!stackExists) {
      const variantNameMessage = variant ? `, ${variant} variant` : "";
      context.error(`Project application %s (%s environment${variantNameMessage}) does not exist.`, folder, env);
      return;
    }
    const hooksParams = {
      context,
      env,
      variant,
      projectApplication
    };
    await (0, _utils.processHooks)("hook-before-destroy", hooksParams);
    await pulumi.run({
      command: "destroy",
      args: {
        debug: inputs.debug || false,
        yes: true
      },
      execa: {
        stdio: "inherit",
        env: (0, _env.createEnvConfiguration)({
          configurations: [(0, _env.withRegion)(inputs), (0, _env.withEnv)(inputs), (0, _env.withEnvVariant)(inputs), (0, _env.withProjectName)(context)]
        })
      }
    });
    console.log();
    context.success(`Done! Destroy finished in %s.`, getDuration());
    await (0, _utils.processHooks)("hook-after-destroy", hooksParams);
  }
});

//# sourceMappingURL=destroy.js.map