"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeMigrationsCommand = void 0;
var _clientLambda = require("@webiny/aws-sdk/client-lambda");
var _utils = require("../utils");
var _cli = require("@webiny/data-migration/cli");
const executeMigrationsCommand = async (params, context) => {
  const apiOutput = (0, _utils.getStackOutput)({
    folder: "apps/api",
    env: params.env,
    variant: params.variant
  });
  context.info("Executing data migration Lambda function...");
  try {
    const lambdaClient = new _clientLambda.LambdaClient({
      region: apiOutput.region
    });
    const functionName = apiOutput["migrationLambdaArn"];
    const logReporter = new _cli.LogReporter(functionName);
    const statusReporter = !process.stdout.isTTY || "CI" in process.env ? new _cli.NonInteractiveCliStatusReporter(logReporter) : new _cli.InteractiveCliStatusReporter(logReporter);
    const runner = _cli.MigrationRunner.create({
      lambdaClient,
      functionName,
      statusReporter
    });
    const result = await runner.runMigration({
      version: process.env.WEBINY_VERSION || context.version,
      pattern: params.pattern,
      force: params.force
    });
    if (result) {
      const reporter = new _cli.CliMigrationRunReporter(logReporter, context);
      await reporter.report(result);
    }
  } catch (e) {
    context.error(`An error occurred while trying to execute data migration Lambda function!`);
    console.log(e);
  }
};
exports.executeMigrationsCommand = executeMigrationsCommand;

//# sourceMappingURL=executeMigrations.js.map