"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _zlib = _interopRequireDefault(require("zlib"));
var _mqtt = _interopRequireDefault(require("./mqtt"));
const webinyWatchArgs = JSON.parse(process.env["WEBINY_WATCH"] || "{}");
const jsonStringifyAndCompress = input => {
  const jsonStringInput = JSON.stringify(input);
  return new Promise(function (resolve, reject) {
    _zlib.default.gzip(jsonStringInput, {}, function (error, result) {
      if (error) {
        reject(error);
      } else {
        resolve(result);
      }
    });
  });
};
const decompressAndJsonParse = async input => {
  const inputBuffer = Buffer.from(input);
  const jsonStringResult = await new Promise(function (resolve, reject) {
    _zlib.default.gunzip(inputBuffer, {}, function (error, result) {
      if (error) {
        reject(error);
      } else {
        resolve(result);
      }
    });
  });
  const value = jsonStringResult?.toString ? jsonStringResult.toString("utf-8") : jsonStringResult;
  return JSON.parse(value);
};
var _default = async (...args) => {
  /**
   * We MUST import local mqtt, do not change!
   */
  // @ts-expect-error
  const client = await _mqtt.default.connectAsync(webinyWatchArgs.iotEndpoint);
  await client.subscribeAsync(webinyWatchArgs.iotEndpointTopic);
  const eventId = new Date().getTime();
  const fnInvocationPayload = {
    eventType: "webiny.watch.functionInvocation",
    eventId,
    data: {
      sessionId: webinyWatchArgs.sessionId,
      functionName: webinyWatchArgs.functionName,
      compressedArgs: await jsonStringifyAndCompress(args),
      env: process.env
    }
  };
  await client.publish(webinyWatchArgs.iotEndpointTopic, JSON.stringify(fnInvocationPayload));
  return new Promise((resolve, reject) => {
    // @ts-expect-error
    client.on("message", async (_, message) => {
      const payload = JSON.parse(message.toString());
      if (payload.eventType !== "webiny.watch.functionInvocationResult") {
        return;
      }
      if (payload.data.originalEventId !== eventId) {
        return;
      }
      if (payload.data.compressedError) {
        const decompressedError = await decompressAndJsonParse(payload.data.compressedError);
        reject(decompressedError);
        return;
      }
      const decompressedResult = await decompressAndJsonParse(payload.data.compressedResult);
      resolve(decompressedResult);
    });
  });
};
exports.default = _default;

//# sourceMappingURL=handler.js.map