"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.listPackages = void 0;
var _execa = _interopRequireDefault(require("execa"));
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
var _utils = require("../../utils");
const listPackages = async ({
  inputs
}) => {
  let packagesList = [];
  if (inputs.package) {
    packagesList = Array.isArray(inputs.package) ? [...inputs.package] : [inputs.package];

    // Also split by commas.
    packagesList = packagesList.map(item => item.split(",")).flat();

    // When providing packages manually, we also allow providing names of Webiny packages
    // without the `@webiny` scope. In that case, we need to add the scope to the package name.
    const webinyPrefixedPackagesToAdd = [];
    for (let i = 0; i < packagesList.length; i++) {
      if (!packagesList[i].startsWith("@webiny")) {
        webinyPrefixedPackagesToAdd.push(`@webiny/${packagesList[i]}`);
      }
    }
    packagesList.push(...webinyPrefixedPackagesToAdd);
  } else {
    const cmd = ["webiny", "workspaces", "tree", "--json", "--depth", String(inputs.depth || ""), "--distinct", "--folder", inputs.folder];
    packagesList = await (0, _execa.default)("yarn", cmd).then(({
      stdout
    }) => {
      return JSON.parse(stdout);
    });
  }
  const commandArgs = ["webiny", "workspaces", "list", "--json", "--withPath", ...packagesList.reduce((current, item) => {
    current.push("--scope", item);
    return current;
  }, [])];
  if (inputs.env) {
    commandArgs.push("--env", inputs.env);
  }
  return (0, _execa.default)("yarn", commandArgs).then(({
    stdout
  }) => {
    const result = JSON.parse(stdout);
    const packages = [];
    for (const packageName in result) {
      const root = result[packageName];
      const configPath = _fs.default.existsSync(_path.default.join(root, "webiny.config.ts")) ? _path.default.join(root, "webiny.config.ts") : _path.default.join(root, "webiny.config.js");

      // We need this because newly introduced extension
      // packages do not have a Webiny config file.
      if (!_fs.default.existsSync(configPath)) {
        continue;
      }
      const config = (0, _utils.requireConfig)(configPath);
      packages.push({
        name: packageName,
        config,
        paths: {
          root,
          config: configPath
        }
      });
    }
    return packages;
  });
};
exports.listPackages = listPackages;

//# sourceMappingURL=listPackages.js.map