"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.replaceLambdaFunctions = void 0;
var _fs = _interopRequireDefault(require("fs"));
var _pRetry = _interopRequireDefault(require("p-retry"));
var _clientLambda = require("@webiny/aws-sdk/client-lambda");
var _utils = require("../../utils");
const WATCH_MODE_NOTE_IN_DESCRIPTION = " (💡 local development mode, redeploy to remove)";
const DEFAULT_INCREASE_TIMEOUT = 120;
const replaceLambdaFunctions = async ({
  folder,
  env,
  variant,
  iotEndpoint,
  iotEndpointTopic,
  sessionId,
  functionsList,
  increaseTimeout,
  context
}) => {
  const stackExport = (0, _utils.getStackExport)({
    folder,
    env,
    variant
  });
  if (!stackExport) {
    // If no stack export is found, return an empty array. This is a valid scenario.
    // For example, watching the Admin app locally, but not deploying it.
    context.debug("No AWS Lambda functions to replace.");
    return [];
  }
  context.debug("replacing %s AWS Lambda function(s).", functionsList.meta.count);
  const lambdaClient = new _clientLambda.LambdaClient();
  const replacementsPromises = functionsList.list.map(async fn => {
    const getFnConfigCmd = new _clientLambda.GetFunctionConfigurationCommand({
      FunctionName: fn.name
    });
    const lambdaFnConfiguration = await lambdaClient.send(getFnConfigCmd);
    const updateFnCodeCmd = new _clientLambda.UpdateFunctionCodeCommand({
      FunctionName: fn.name,
      ZipFile: _fs.default.readFileSync(__dirname + "/handler/handler.zip")
    });
    await lambdaClient.send(updateFnCodeCmd);
    let Description = lambdaFnConfiguration.Description || "";
    if (!Description.endsWith(WATCH_MODE_NOTE_IN_DESCRIPTION)) {
      Description += WATCH_MODE_NOTE_IN_DESCRIPTION;
    }
    const Timeout = increaseTimeout || DEFAULT_INCREASE_TIMEOUT;
    await (0, _pRetry.default)(() => lambdaClient.send(new _clientLambda.UpdateFunctionConfigurationCommand({
      FunctionName: fn.name,
      Timeout,
      Description,
      Environment: {
        Variables: {
          ...lambdaFnConfiguration.Environment?.Variables,
          WEBINY_WATCH: JSON.stringify({
            enabled: true,
            sessionId,
            iotEndpoint,
            iotEndpointTopic,
            functionName: fn.name
          })
        }
      }
    })));
  });
  return Promise.all(replacementsPromises).then(res => {
    context.debug("%s AWS Lambda function(s) replaced.", functionsList.meta.count);
    return res;
  });
};
exports.replaceLambdaFunctions = replaceLambdaFunctions;

//# sourceMappingURL=replaceLambdaFunctions.js.map