"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.outputCommand = void 0;
var _utils = require("../utils");
var _env = require("../utils/env");
const outputCommand = exports.outputCommand = (0, _utils.createPulumiCommand)({
  name: "output",
  createProjectApplicationWorkspace: false,
  command: async ({
    inputs,
    context,
    pulumi
  }) => {
    const {
      env,
      variant,
      folder,
      json
    } = inputs;
    const stackName = (0, _utils.getStackName)({
      env,
      variant
    });
    let stackExists = true;
    try {
      const PULUMI_SECRETS_PROVIDER = process.env.PULUMI_SECRETS_PROVIDER;
      await pulumi.run({
        command: ["stack", "select", `${stackName}`],
        args: {
          secretsProvider: PULUMI_SECRETS_PROVIDER
        },
        execa: {
          env: (0, _env.createEnvConfiguration)({
            configurations: [(0, _env.withPulumiConfigPassphrase)()]
          })
        }
      });
    } catch (e) {
      stackExists = false;
    }
    if (stackExists) {
      return await pulumi.run({
        command: ["stack", "output"],
        args: {
          json: !!json
        },
        execa: {
          stdio: "inherit"
        }
      });
    }
    if (json) {
      return console.log(JSON.stringify(null));
    }
    const variantMessage = variant ? `, %s variant` : "";
    context.error(`Project application %s (%s environment${variantMessage}) does not exist.`, folder, env, variant);
  }
});

//# sourceMappingURL=output.js.map