"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDeployedSystemFactory = exports.DeployedSystem = void 0;
var _utils = require("../../utils");
class DeployedSystem {
  constructor(params) {
    this.env = params.env;
    this.variant = params.variant;
    this.stacks = params.stacks;
  }
  getStack(app) {
    const stack = this.stacks.find(stack => stack.app === app);
    if (!stack) {
      throw new _utils.GracefulError(`Stack for application "${app}" not found.`);
    }
    return stack;
  }
}
exports.DeployedSystem = DeployedSystem;
const createDeployedSystemFactory = ({
  folders
}) => {
  return params => {
    if (!params.stacks.length) {
      throw new _utils.GracefulError(`No stacks found for the system.`);
    }
    const {
      env,
      variant
    } = params.stacks[0];
    for (const folder of folders) {
      const exists = params.stacks.some(stack => stack.folder === folder);
      if (!exists) {
        throw new _utils.GracefulError(`Stack for application "${folder}" is missing in system env "${env}", variant "${variant || ""}".`);
      }
    }
    return new DeployedSystem({
      ...params,
      env,
      variant
    });
  };
};
exports.createDeployedSystemFactory = createDeployedSystemFactory;

//# sourceMappingURL=DeployedSystem.js.map