"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeSetPrimaryVariantCommand = void 0;
var _getDeployedSystems = require("./getDeployedSystems");
var _ConnectionSystem = require("./ConnectionSystem");
const folders = ["apps/core", "apps/api"];
const executeSetPrimaryVariantCommand = async (inputs, context) => {
  const {
    confirm
  } = inputs;
  const {
    primary,
    secondary
  } = await (0, _getDeployedSystems.getDeployedSystems)({
    context,
    env: inputs.env,
    primary: inputs.primary,
    secondary: inputs.secondary,
    folders
  });
  /**
   * Let's say we have a connection between primary and secondary systems.
   */
  const connection = (0, _ConnectionSystem.createConnectionSystem)({
    context,
    primary,
    secondary
  });
  /**
   * We would need to build that connection.
   */
  await connection.build();
  /**
   * And then we can actually deploy it, if confirmed.
   */
  if (!confirm) {
    context.error(`Setting primary variant${inputs.primary ? ` "${inputs.primary}"` : ""} is not confirmed. Please add "--confirm" argument to your command to actually deploy changes.`);
    return;
  }
  await connection.deploy();
};
exports.executeSetPrimaryVariantCommand = executeSetPrimaryVariantCommand;

//# sourceMappingURL=executeSetPrimaryVariantCommand.js.map