"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.pulumiRunCommand = void 0;
var _utils = require("../utils");
var _env = require("../utils/env");
const pulumiRunCommand = exports.pulumiRunCommand = (0, _utils.createPulumiCommand)({
  name: "pulumi",
  createProjectApplicationWorkspace: false,
  command: async ({
    inputs,
    context,
    pulumi
  }) => {
    const [, ...command] = inputs._;
    const {
      env,
      variant,
      folder,
      debug
    } = inputs;
    const stackName = (0, _utils.getStackName)({
      env,
      variant
    });
    if (env) {
      debug && context.debug(`Environment provided - selecting %s Pulumi stack.`, stackName);
      let stackExists = true;
      try {
        const PULUMI_SECRETS_PROVIDER = process.env.PULUMI_SECRETS_PROVIDER;
        await pulumi.run({
          command: ["stack", "select", stackName],
          args: {
            secretsProvider: PULUMI_SECRETS_PROVIDER
          },
          execa: {
            env: (0, _env.createEnvConfiguration)({
              configurations: [(0, _env.withPulumiConfigPassphrase)()]
            })
          }
        });
      } catch (e) {
        stackExists = false;
      }
      if (!stackExists) {
        const variantNameMessage = variant ? `, ${context.error.hl(variant)} variant` : "";
        throw new Error(`Project application ${context.error.hl(folder)} (${context.error.hl(env)} environment${variantNameMessage}) does not exist.`);
      }
    }
    if (debug) {
      debug && context.debug(`Running the following command in %s folder: %s`, folder, "pulumi " + command.join(" "));
    }
    return pulumi.run({
      command: command,
      execa: {
        stdio: "inherit",
        env: (0, _env.createEnvConfiguration)({
          configurations: [(0, _env.withRegion)(inputs), (0, _env.withEnv)(inputs), (0, _env.withEnvVariant)(inputs), (0, _env.withProjectName)(context)]
        })
      }
    });
  }
});

//# sourceMappingURL=pulumiRun.js.map