"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.listPackages = void 0;
var _execa = _interopRequireDefault(require("execa"));
var _WebinyConfigFile = require("./WebinyConfigFile");
var _utils = require("../../utils");
const listPackages = async ({
  inputs
}) => {
  let packagesList = [];
  if (inputs.package) {
    packagesList = Array.isArray(inputs.package) ? inputs.package : [inputs.package];
  } else {
    packagesList = await (0, _execa.default)("yarn", ["webiny", "workspaces", "tree", "--json", "--depth", String(inputs.depth || ""), "--distinct", "--folder", inputs.folder]).then(({
      stdout
    }) => JSON.parse(stdout));
  }
  const commandArgs = ["webiny", "workspaces", "list", "--json", "--withPath", ...packagesList.reduce((current, item) => {
    current.push("--scope", item);
    return current;
  }, [])];
  if (inputs.env) {
    commandArgs.push("--env", inputs.env);
  }
  return (0, _execa.default)("yarn", commandArgs).then(({
    stdout
  }) => {
    const result = JSON.parse(stdout);
    const packages = [];
    for (const packageName in result) {
      const root = result[packageName];
      const configPath = _WebinyConfigFile.WebinyConfigFile.forWorkspace(root).getAbsolutePath();
      if (!configPath) {
        continue;
      }
      const config = (0, _utils.requireConfig)(configPath);
      packages.push({
        name: packageName,
        config,
        paths: {
          root,
          config: configPath
        }
      });
    }
    return packages;
  });
};
exports.listPackages = listPackages;

//# sourceMappingURL=listPackages.js.map