"use strict";

var _worker_threads = require("worker_threads");
var _cli = require("@webiny/cli");
var _utils = require("../../utils");
// We need this because tools have internal console.log calls. So,
// let's intercept those and make sure messages are just forwarded
// to the main thread.
const types = ["log", "error", "warn"];
for (let i = 0; i < types.length; i++) {
  const type = types[i];
  console[type] = (...message) => {
    _worker_threads.parentPort.postMessage(JSON.stringify({
      type,
      message: message.filter(Boolean).map(m => {
        if (m instanceof Error) {
          return m.message;
        }
        return m;
      })
    }));
  };
}
(async () => {
  try {
    const {
      options,
      package: pckg
    } = _worker_threads.workerData;
    const config = (0, _utils.requireConfigWithExecute)(pckg.config, {
      options: {
        ...options,
        cwd: pckg.root
      },
      context: _cli.cli
    });
    if (typeof config.commands.watch !== "function") {
      console.log(`Skipping watch; ${_cli.cli.warning.hl("watch")} command is missing. Check package's ${_cli.cli.warning.hl("webiny.config.ts")} file.`);
      return;
    }
    await config.commands.watch(options, _cli.cli);
  } catch (e) {
    console.log(e.stack);
    console.error(e);
  }
})();

//# sourceMappingURL=worker.js.map