"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GracefulPulumiError = void 0;
var _GracefulError = require("./GracefulError");
var _gracefulPulumiErrorHandlers = require("./gracefulPulumiErrorHandlers");
class GracefulPulumiError extends _GracefulError.GracefulError {
  static from(ex, context) {
    if (ex instanceof _GracefulError.GracefulError) {
      return ex;
    }
    for (const handler of _gracefulPulumiErrorHandlers.gracefulPulumiErrorHandlers) {
      const result = handler({
        error: ex,
        context
      });
      if (!result) {
        continue;
      }
      let errorMessage = result;
      if (typeof errorMessage === "object") {
        const {
          message,
          learnMore
        } = errorMessage;
        errorMessage = message;
        if (learnMore) {
          errorMessage += ` Learn more: ${learnMore}.`;
        }
      }
      return new GracefulPulumiError(errorMessage, {
        cause: ex
      });
    }
    return undefined;
  }
}
exports.GracefulPulumiError = GracefulPulumiError;

//# sourceMappingURL=GracefulPulumiError.js.map