"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.uploadFolderToS3 = void 0;
var _isString = _interopRequireDefault(require("lodash/isString"));
var _chunk = _interopRequireDefault(require("lodash/chunk"));
var _fs = _interopRequireDefault(require("fs"));
var _clientS = require("@webiny/aws-sdk/client-s3");
var _mime = _interopRequireDefault(require("mime"));
var _path = require("path");
var _crawlDirectory = require("../crawlDirectory");
var _crypto = _interopRequireDefault(require("crypto"));
function getFileChecksum(file) {
  const hash = _crypto.default.createHash("md5");
  return new Promise(resolve => {
    const stream = _fs.default.createReadStream(file);
    stream.on("data", function (data) {
      hash.update(data, "utf8");
    });
    stream.on("end", function () {
      resolve(hash.digest("hex"));
    });
  });
}
/**
 * TODO @adrian
 * This is not used anywhere.
 */
const uploadFolderToS3 = async ({
  path: root,
  bucket,
  onFileUploadSuccess,
  onFileUploadError,
  onFileUploadSkip,
  acl = "public-read",
  cacheControl: initialCacheControl = "max-age=31536000"
}) => {
  const s3 = (0, _clientS.createS3)({
    region: process.env.AWS_REGION
  });
  if (!_fs.default.existsSync(root)) {
    throw new Error("Cannot continue, folder does not exist.");
  }
  const paths = [];
  await (0, _crawlDirectory.crawlDirectory)(root, async path => {
    paths.push(path);
  });
  const pathsChunks = (0, _chunk.default)(paths, 20);
  let cacheControl = [];
  if ((0, _isString.default)(cacheControl)) {
    /**
     * TODO @adrian
     *
     * pattern should be a string.
     * Left it here for now.
     */
    // @ts-expect-error
    cacheControl = [{
      pattern: /.*/,
      value: cacheControl
    }];
  } else {
    cacheControl = initialCacheControl;
  }
  for (let i = 0; i < pathsChunks.length; i++) {
    const chunk = pathsChunks[i];
    const promises = [];
    for (let j = 0; j < chunk.length; j++) {
      const path = chunk[j];
      promises.push(new Promise(async resolve => {
        // We also replace "\" with "/", which can occur on Windows' CMD or Powershell.
        // https://github.com/webiny/webiny-js/issues/1701#issuecomment-860123555
        const key = (0, _path.relative)(root, path).replace(/\\/g, "/");
        try {
          // Get file checksum so that we can check if a file needs to be uploaded or not.
          const checksum = await getFileChecksum(path);
          let skipUpload = false;
          try {
            const cmd = new _clientS.HeadObjectCommand({
              Bucket: bucket,
              Key: key
            });
            const existingObject = await s3.send(cmd);
            if (existingObject.Metadata?.checksum === checksum) {
              skipUpload = true;
            }
          } catch {
            // Do nothing.
          }
          if (skipUpload) {
            if (typeof onFileUploadSkip === "function") {
              await onFileUploadSkip({
                paths: {
                  full: path,
                  relative: key
                }
              });
            }
          } else {
            /**
             * TODO @adrian
             *
             * Check the cache control here.
             */
            let cmdCacheControl;
            if (cacheControl.length) {
              cmdCacheControl = cacheControl.find(x =>
              // @ts-expect-error
              x?.pattern?.test(key))?.value;
            }
            const cmd = new _clientS.PutObjectCommand({
              Bucket: bucket,
              Key: key,
              ACL: acl,
              CacheControl: cmdCacheControl,
              ContentType: _mime.default.getType(path) || undefined,
              Body: _fs.default.readFileSync(path),
              Metadata: {
                checksum
              }
            });
            await s3.send(cmd);
            if (typeof onFileUploadSuccess === "function") {
              await onFileUploadSuccess({
                paths: {
                  full: path,
                  relative: key
                }
              });
            }
          }
          resolve();
        } catch (e) {
          if (typeof onFileUploadError === "function") {
            await onFileUploadError({
              paths: {
                full: path,
                relative: key
              },
              error: e
            });
          }
          resolve();
        }
      }));
    }
    await Promise.all(promises);
  }
};
exports.uploadFolderToS3 = uploadFolderToS3;

//# sourceMappingURL=uploadFolderToS3.js.map