"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPulumi = void 0;
var _chalk = require("chalk");
var _pulumiSdk = require("@webiny/pulumi-sdk");
var _ora = _interopRequireDefault(require("ora"));
var _merge = _interopRequireDefault(require("lodash/merge"));
var _utils = require("@webiny/cli/utils");
var _path = _interopRequireDefault(require("path"));
var _fs = _interopRequireDefault(require("fs"));
const getPulumi = async ({
  projectApplication,
  pulumi,
  install
} = {}) => {
  const spinner = (0, _ora.default)();
  let cwd;

  // When running the `webiny deploy` command without specifying the
  // project application, the `projectApplication` variable is empty.
  if (projectApplication) {
    cwd = projectApplication.paths.workspace;
    if (!_fs.default.existsSync(cwd)) {
      const cmd = `yarn webiny build ${projectApplication.paths.relative} --env {environment}`;
      const message = ["The command cannot be run because the project application hasn't been built. ", "To build it, run ", (0, _chalk.red)(cmd), "."].join("");
      throw new Error(message);
    }
  }
  const instance = new _pulumiSdk.Pulumi((0, _merge.default)({
    pulumiFolder: _path.default.join((0, _utils.getProject)().root, ".webiny"),
    beforePulumiInstall: () => {
      console.log(`It looks like this is your first time using ${(0, _chalk.green)("@webiny/pulumi-sdk")}.`);
      spinner.start(`Downloading Pulumi...`);
    },
    afterPulumiInstall: () => {
      spinner.stopAndPersist({
        symbol: (0, _chalk.green)("✔"),
        text: `Pulumi downloaded, continuing...`
      });
    }
  }, {
    execa: {
      cwd
    }
  }, pulumi));

  // Run install method, just in case Pulumi wasn't installed yet.
  if (install !== false) {
    await instance.install();
  }
  return instance;
};
exports.getPulumi = getPulumi;

//# sourceMappingURL=getPulumi.js.map