"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStackExport = void 0;
var _execa = _interopRequireDefault(require("execa"));
var _utils = require("@webiny/cli/utils");
const cache = {};
const runPulumiStackExport = ({
  folder,
  env,
  variant,
  cwd
}) => {
  const project = (0, _utils.getProject)();
  const cacheKey = [folder, env, variant].filter(Boolean).join("_");
  if (cache[cacheKey]) {
    return structuredClone(cache[cacheKey]);
  }
  try {
    const command = ["webiny", "pulumi", folder, "--env", env];
    if (variant) {
      command.push("--variant", variant);
    }
    command.push("--", "stack", "export");
    const {
      stdout
    } = _execa.default.sync("yarn", command.filter(Boolean), {
      cwd: cwd || project.root
    });
    const parsed = JSON.parse(stdout);
    if (Object.keys(parsed).length === 0) {
      return null;
    }
    cache[cacheKey] = parsed;
    return structuredClone(cache[cacheKey]);
  } catch (e) {
    return null;
  }
};
const getStackExport = args => {
  if (!args.folder) {
    throw new Error(`Please specify a project application folder, for example "apps/admin".`);
  }
  if (!args.env) {
    throw new Error(`Please specify environment, for example "dev".`);
  }
  return runPulumiStackExport(args);
};
exports.getStackExport = getStackExport;

//# sourceMappingURL=getStackExport.js.map