"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getStackOutput = void 0;
var _utils = require("@webiny/cli/utils");
var _mapStackOutput = require("./mapStackOutput");
var _execa = _interopRequireDefault(require("execa"));
const cache = {};
const getOutputJson = params => {
  const {
    folder,
    env,
    cwd,
    variant
  } = params;
  const project = (0, _utils.getProject)();
  const cacheKey = [folder, env, variant].filter(Boolean).join("_");
  const skipCache = params.skipCache === true;
  if (cache[cacheKey] && !skipCache) {
    return structuredClone(cache[cacheKey]);
  }
  try {
    const command = ["webiny", "output", folder, "--env", env, "--json", "--no-debug"];
    if (variant) {
      command.push("--variant", variant);
    }
    const {
      stdout
    } = _execa.default.sync("yarn", command, {
      cwd: cwd || project.root
    });

    // Let's get the output after the first line break. Everything before is just yarn stuff.
    const extractedJSON = stdout.substring(stdout.indexOf("{"));
    const parsed = JSON.parse(extractedJSON);
    if (Object.keys(parsed).length === 0) {
      return null;
    }
    cache[cacheKey] = parsed;
    return structuredClone(cache[cacheKey]);
  } catch (e) {
    return null;
  }
};
const getStackOutput = (folderOrArgs, env, map) => {
  if (!folderOrArgs) {
    throw new Error("Missing initial argument.");
  }

  // Normalize arguments.
  let args = {};
  if (typeof folderOrArgs === "string") {
    args = {
      folder: folderOrArgs,
      env: env,
      map: map
    };
  } else {
    args = folderOrArgs;
  }
  if (!args.folder) {
    throw new Error(`Please specify a project application folder, for example "admin".`);
  }
  if (!args.env) {
    throw new Error(`Please specify environment, for example "dev".`);
  }
  const output = getOutputJson({
    folder: args.folder,
    env: args.env,
    variant: args.variant,
    cwd: args.cwd,
    skipCache: args.skipCache
  });
  if (!output) {
    return output;
  }
  if (!args.map) {
    return output;
  }
  return (0, _mapStackOutput.mapStackOutput)(output, args.map);
};
exports.getStackOutput = getStackOutput;

//# sourceMappingURL=getStackOutput.js.map