"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.login = void 0;
var _getPulumi = require("./getPulumi");
var _trimEnd = _interopRequireDefault(require("lodash/trimEnd"));
var _fs = _interopRequireDefault(require("fs"));
var _path = require("path");
// To use a self-managed backend, specify a storage endpoint URL as pulumi login’s <backend-url> argument:
// s3://<bucket-path>, azblob://<container-path>, gs://<bucket-path>, or file://<fs-path>.
// This will tell Pulumi to store state in AWS S3, Azure Blob Storage, Google Cloud Storage, or the
// local filesystem, respectively.
// @see https://www.pulumi.com/docs/intro/concepts/state/#logging-into-the-pulumi-service-backend

const SELF_MANAGED_BACKEND = ["s3://", "azblob://", "gs://"];
const login = async projectApplication => {
  // Do the login with Pulumi CLI.
  const pulumi = await (0, _getPulumi.getPulumi)({
    projectApplication
  });
  const projectAppRelativePath = projectApplication.paths.relative;

  // A couple of variations here, just to preserve backwards compatibility.
  let loginUrl = process.env.WEBINY_PULUMI_BACKEND || process.env.WEBINY_PULUMI_BACKEND_URL || process.env.PULUMI_LOGIN;
  if (loginUrl) {
    // If the user passed `s3://my-bucket`, we want to store files in `s3://my-bucket/{project-application-path}`
    const selfManagedBackend = SELF_MANAGED_BACKEND.find(item => loginUrl.startsWith(item));
    if (selfManagedBackend) {
      loginUrl = (0, _trimEnd.default)(loginUrl, "/") + "/" + projectAppRelativePath;
      loginUrl = loginUrl.replace(/\\/g, "/");
    }
  } else {
    // By default, we use local file system as backend. All files are stored in project root's
    // `.pulumi` folder, e.g. `.pulumi/apps/admin`.
    const stateFilesFolder = (0, _path.join)(projectApplication.project.root, ".pulumi", projectAppRelativePath);
    if (!_fs.default.existsSync(stateFilesFolder)) {
      _fs.default.mkdirSync(stateFilesFolder, {
        recursive: true
      });
    }
    loginUrl = `file://${stateFilesFolder}`;
  }
  await pulumi.run({
    command: ["login", loginUrl]
  });
  return {
    login: loginUrl
  };
};
exports.login = login;

//# sourceMappingURL=login.js.map