"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processHooks = void 0;
var _GracefulError = require("./GracefulError");
const processHooks = async (hook, {
  context,
  ...options
}) => {
  const plugins = context.plugins.byType(hook);
  for (let i = 0; i < plugins.length; i++) {
    try {
      await plugins[i].hook(options, context);
    } catch (err) {
      if (err instanceof _GracefulError.GracefulError) {
        throw err;
      }
      err.message = `An error occurred while processing ${context.error.hl(plugins[i].name)} plugin: ${err.message}`;
      throw err;
    }
  }
};
exports.processHooks = processHooks;

//# sourceMappingURL=processHooks.js.map