"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getApplicationsStacks = void 0;
var _path = _interopRequireDefault(require("path"));
var _fs = _interopRequireDefault(require("fs"));
var _fastGlob = _interopRequireDefault(require("fast-glob"));
var _utils = require("@webiny/cli/utils");
var _ = require("./..");
var _Stack = require("./Stack");
const getApplicationsStacks = params => {
  const project = (0, _utils.getProject)();
  const {
    folders,
    env,
    cwd,
    variants
  } = params;
  return folders.map(folder => {
    const app = folder.split("/").pop();
    if (!app) {
      throw new _.GracefulError(`Cannot determine application name from folder: ${folder}`);
    }
    const target = _path.default.join(cwd || project.root, ".pulumi", folder, ".pulumi", "stacks", app);
    if (!_fs.default.existsSync(target)) {
      throw new _.GracefulError(`Stacks folder "${target}" does not exist. Did you deploy the "${folder}" application?`);
    }
    const match = `${target}/${env}*.json`;
    const stacks = _fastGlob.default.sync(match, {}).map(file => {
      const parts = file.replace(".json", "").split("/");
      const part = parts.pop();
      if (!part) {
        return null;
      }
      const {
        env,
        variant
      } = (0, _.splitStackName)(part);
      if (variants && variant && !variants.includes(variant)) {
        return null;
      }
      return (0, _Stack.createStack)({
        env,
        variant,
        app,
        folder
      });
    }).filter(item => !!item);
    if (!stacks.length) {
      throw new _.GracefulError(`There are no stacks in "${target}" for environment "${env}".`);
    }
    return {
      app,
      env,
      folder,
      stacks
    };
  });
};
exports.getApplicationsStacks = getApplicationsStacks;

//# sourceMappingURL=getApplicationsStacks.js.map